@@ -125,7 +125,7 @@ def escape_cdata(text):
     return text
 
 def contains_bitcoin_addr(text, errors):
-    if text != None and ADDRESS_REGEXP.search(text) != None:
+    if text is not None and ADDRESS_REGEXP.search(text) is not None:
         errors.append('Translation "%s" contains a bitcoin address. This will be removed.' % (text))
         return True
     return False
