@@ -6,13 +6,15 @@
 #include <noui.h>
 
 #include <ui_interface.h>
-#include <util.h>
+#include <util/system.h>
 
 #include <cstdio>
 #include <stdint.h>
 #include <string>
 
-static bool noui_ThreadSafeMessageBox(const std::string& message, const std::string& caption, unsigned int style)
+#include <boost/signals2/connection.hpp>
+
+bool noui_ThreadSafeMessageBox(const std::string& message, const std::string& caption, unsigned int style)
 {
     bool fSecure = style & CClientUIInterface::SECURE;
     style &= ~CClientUIInterface::SECURE;
@@ -35,24 +37,23 @@ static bool noui_ThreadSafeMessageBox(const std::string& message, const std::str
 
     if (!fSecure)
         LogPrintf("%s: %s\n", strCaption, message);
-    fprintf(stderr, "%s: %s\n", strCaption.c_str(), message.c_str());
+    tfm::format(std::cerr, "%s: %s\n", strCaption.c_str(), message.c_str());
     return false;
 }
 
-static bool noui_ThreadSafeQuestion(const std::string& /* ignored interactive message */, const std::string& message, const std::string& caption, unsigned int style)
+bool noui_ThreadSafeQuestion(const std::string& /* ignored interactive message */, const std::string& message, const std::string& caption, unsigned int style)
 {
     return noui_ThreadSafeMessageBox(message, caption, style);
 }
 
-static void noui_InitMessage(const std::string& message)
+void noui_InitMessage(const std::string& message)
 {
     LogPrintf("init message: %s\n", message);
 }
 
 void noui_connect()
 {
-    // Connect bitcoind signal handlers
-    uiInterface.ThreadSafeMessageBox.connect(noui_ThreadSafeMessageBox);
-    uiInterface.ThreadSafeQuestion.connect(noui_ThreadSafeQuestion);
-    uiInterface.InitMessage.connect(noui_InitMessage);
+    uiInterface.ThreadSafeMessageBox_connect(noui_ThreadSafeMessageBox);
+    uiInterface.ThreadSafeQuestion_connect(noui_ThreadSafeQuestion);
+    uiInterface.InitMessage_connect(noui_InitMessage);
 }
