@@ -50,5 +50,9 @@ static const int MAX_URI_LENGTH = 255;
 #define QAPP_ORG_DOMAIN "litecoin.org"
 #define QAPP_APP_NAME_DEFAULT "Litecoin-Qt"
 #define QAPP_APP_NAME_TESTNET "Litecoin-Qt-testnet"
+#define QAPP_APP_NAME_REGTEST "Litecoin-Qt-regtest"
+
+/* One gigabyte (GB) in bytes */
+static constexpr uint64_t GB_BYTES{1000000000};
 
 #endif // BITCOIN_QT_GUICONSTANTS_H
