@@ -237,10 +237,6 @@
         <source>&amp;Overview</source>
         <translation>Агляд</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Вузел</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Паказвае агульныя звесткі аб гаманцы</translation>
@@ -285,14 +281,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Change Passphrase...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>Адрасы дасылання...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Адрасы прымання...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Адчыниць &amp;URI...</translation>
@@ -329,10 +317,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Гаманец</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>Даслаць</translation>
@@ -687,10 +671,6 @@
         <source>Options</source>
         <translation>Опцыі</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>Мб</translation>
-    </message>
     <message>
         <source>W&amp;allet</source>
         <translation>Гаманец</translation>
@@ -1202,6 +1182,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
