@@ -135,6 +135,10 @@
         <source>Repeat new passphrase</source>
         <translation>Въведете новата парола повторно</translation>
     </message>
+    <message>
+        <source>Show password</source>
+        <translation>Покажи парола</translation>
+    </message>
     <message>
         <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
         <translation>Въведете новата парола към портфейла.&lt;br/&gt;Моля ползвайте парола съставена от &lt;b&gt;десет или повече произволни символа&lt;/b&gt;, или &lt;b&gt;осем или повече думи&lt;/b&gt;.</translation>
@@ -245,10 +249,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Баланс</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Сървър</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Обобщена информация за портфейла</translation>
@@ -305,18 +305,14 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Смяна на паролата...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Изпращане на адресите...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Получаване на адресите...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Отвори &amp;URI...</translation>
     </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Портфейл</translation>
+    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Натиснете за деактивиране на мрежата</translation>
@@ -329,6 +325,10 @@
         <source>Click to enable network activity again.</source>
         <translation>Натиснете за повторно активиране на мрежата.</translation>
     </message>
+    <message>
+        <source>Syncing Headers (%1%)...</source>
+        <translation>Синхронизиране на хедъри (%1%)</translation>
+    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>Повторно индексиране на блоковете на диска...</translation>
@@ -361,10 +361,6 @@
         <source>Litecoin</source>
         <translation>Биткоин</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Портфейл</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Изпращане</translation>
@@ -469,6 +465,18 @@
         <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
         <translation>Покажи %1 помощно съобщение за да получиш лист с възможни Litecoin команди</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>Портфейл по подразбиране</translation>
+    </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Прозорец</translation>
+    </message>
+    <message>
+        <source>Minimize</source>
+        <translation>Минимизирай</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 клиент</translation>
@@ -851,10 +859,6 @@
         <source>Size of &amp;database cache</source>
         <translation>Размер на кеша в &amp;базата данни</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>Мегабайта</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>Брой на скриптове и &amp;нишки за потвърждение</translation>
@@ -875,6 +879,10 @@
         <source>&amp;Network</source>
         <translation>&amp;Мрежа</translation>
     </message>
+    <message>
+        <source>GB</source>
+        <translation>ГБ</translation>
+    </message>
     <message>
         <source>W&amp;allet</source>
         <translation>По&amp;ртфейл</translation>
@@ -899,6 +907,14 @@
         <source>Map port using &amp;UPnP</source>
         <translation>Отваряне на входящия порт чрез &amp;UPnP</translation>
     </message>
+    <message>
+        <source>Accept connections from outside.</source>
+        <translation>Позволи външни връзки</translation>
+    </message>
+    <message>
+        <source>Allow incomin&amp;g connections</source>
+        <translation>Позволи входящи връзки</translation>
+    </message>
     <message>
         <source>Connect to the Litecoin network through a SOCKS5 proxy.</source>
         <translation>Свързване с Litecoin мрежата чрез SOCKS5  прокси.</translation>
@@ -919,6 +935,10 @@
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Порт на прокси сървъра (пр. 9050)</translation>
     </message>
+    <message>
+        <source>Tor</source>
+        <translation>Тор</translation>
+    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Прозорец</translation>
@@ -979,6 +999,10 @@
         <source>Client restart required to activate changes.</source>
         <translation>Изисква се рестартиране на клиента за активиране на извършените промени.</translation>
     </message>
+    <message>
+        <source>Client will be shut down. Do you want to proceed?</source>
+        <translation>Клиентът ще бъде изключен. Искате ли да продължите?</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Грешка</translation>
@@ -2246,6 +2270,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     <message>
@@ -2259,7 +2286,11 @@
         <source>Send Coins</source>
         <translation>Изпращане</translation>
     </message>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>Портфейл по подразбиране</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     <message>
