@@ -201,10 +201,6 @@
         <source>&amp;Overview</source>
         <translation>Преглед</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Възел</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Покажи общ преглед на портфейла</translation>
@@ -261,14 +257,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>Промени паролата...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>Адреси за пращане...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Адреси за получаване...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Отвори URI</translation>
@@ -277,10 +265,6 @@
         <source>Reindexing blocks on disk...</source>
         <translation>Повторно индексиране на блоковете на диска...</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>портфейл</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;изпращам</translation>
@@ -874,6 +858,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
