@@ -237,10 +237,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Panorama general</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Node</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Mostra el panorama general del moneder</translation>
@@ -285,14 +281,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Canvia la contrasenya...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>Adreces d'e&amp;nviament...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Adreces de &amp;recepció</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Obri un &amp;URI...</translation>
@@ -329,10 +317,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Moneder</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Envia</translation>
@@ -425,6 +409,10 @@
         <source>Up to date</source>
         <translation>Al dia</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Finestra</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>S'està posant al dia ...</translation>
@@ -791,10 +779,6 @@
         <source>Size of &amp;database cache</source>
         <translation>Mida de la memòria cau de la base de &amp;dades</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>Nombre de fils de &amp;verificació d'scripts</translation>
@@ -811,10 +795,6 @@
         <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
         <translation>URL de terceres parts (p. ex. explorador de blocs) que apareix en la pestanya de transaccions com elements del menú contextual. %s en l'URL es reemplaçat pel resum de la transacció. Diferents URL estan separades per una barra vertical |.</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>Opcions de línies d'orde active que sobreescriuen les opcions de dalt:</translation>
-    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>Reestableix totes les opcions del client.</translation>
@@ -1632,14 +1612,6 @@
         <source>Hide</source>
         <translation>Amaga</translation>
     </message>
-    <message>
-        <source>Paying only the minimum fee is just fine as long as there is less transaction volume than space in the blocks. But be aware that this can end up in a never confirming transaction once there is more demand for litecoin transactions than the network can process.</source>
-        <translation>No hi ha cap problema en pagar només la comissió mínima sempre que hi haja menys volum de transacció que espai en els blocs. Però tingueu present que això pot acabar en una transacció que mai es confirme una vegada hi haja més demanda de transaccions de litecoins que la xarxa puga processar.</translation>
-    </message>
-    <message>
-        <source>(read the tooltip)</source>
-        <translation>(llegiu l'indicador de funció)</translation>
-    </message>
     <message>
         <source>Recommended:</source>
         <translation>Recomanada:</translation>
@@ -2406,6 +2378,9 @@
         <translation>Unitat en què mostrar els imports. Feu clic per seleccionar una altra unitat.</translation>
     </message>
 </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     <message>
