@@ -21,6 +21,10 @@
         <source>&amp;Copy</source>
         <translation>&amp;Kopírovat</translation>
     </message>
+    <message>
+        <source>C&amp;lose</source>
+        <translation>Z&amp;avřít</translation>
+    </message>
     <message>
         <source>Delete the currently selected address from the list</source>
         <translation>Odstraní aktuálně vybrané adresy ze seznamu</translation>
@@ -37,6 +41,18 @@
         <source>&amp;Delete</source>
         <translation>&amp;Odstranit</translation>
     </message>
+    <message>
+        <source>C&amp;hoose</source>
+        <translation>V&amp;ybrat</translation>
+    </message>
+    <message>
+        <source>&amp;Copy Address</source>
+        <translation>&amp;Kopírovat adresu</translation>
+    </message>
+    <message>
+        <source>&amp;Edit</source>
+        <translation>&amp;Upravit</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>Textový soubor oddělený středníkem (*.csv)</translation>
@@ -71,6 +87,10 @@
         <source>Repeat new passphrase</source>
         <translation>Zopakujte nové heslo</translation>
     </message>
+    <message>
+        <source>Show password</source>
+        <translation>Zobrazit heslo</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Zašifrovat peněženku</translation>
@@ -255,10 +275,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adresa</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Nová adresa pro příjem</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Nová adresa k odeslání</translation>
@@ -271,10 +287,6 @@
         <source>Edit sending address</source>
         <translation>Upravit adresu k odeslání</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Zadaná adresa "%1" se již v seznamu adres nachází.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Nemohu odemknout peněženku</translation>
@@ -289,10 +301,6 @@
     </context>
 <context>
     <name>HelpMessageDialog</name>
-    <message>
-        <source>Usage:</source>
-        <translation>Použití:</translation>
-    </message>
     </context>
 <context>
     <name>Intro</name>
@@ -388,6 +396,10 @@
         <source>Message</source>
         <translation>Zpráva</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Peněženka</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -513,10 +525,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>Potvrzeno (%1 potvrzení)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Tento blok nebyl přijat žádným dalším uzlem a pravděpodobně nebude akceptován!</translation>
-    </message>
     <message>
         <source>Received with</source>
         <translation>Přijato s</translation>
@@ -644,6 +652,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
@@ -663,10 +674,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Možnosti:</translation>
-    </message>
     <message>
         <source>Loading wallet...</source>
         <translation>Načítání peněženky...</translation>
