@@ -175,10 +175,6 @@
         <source>Wallet encrypted</source>
         <translation>Waled Wedi Amgryptio</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>Bydd %1 nawr yn gorffen y broses amgryptio. Cofiwch nad ydy amgryptio eich waled yn llawn amddiffyn eich litecoins rhag cael eu dwyn gan afiechyd yn heintio eich cyfrifiadur.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>PWYSIG: Mi ddylai unrhyw back ups blaenorol rydych wedi ei wneud o ffeil eich waled gael ei ddiweddaru efo'r ffeil amgryptiedig newydd ei chreu. Am resymau diogelwch, bydd back ups blaenorol o ffeil y walet heb amgryptio yn ddiwerth mor fuan ac yr ydych yn dechrau defnyddio'r waled amgryptiedig newydd.</translation>
@@ -241,10 +237,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Trosolwg</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Nod</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Dangos trosolwg cyffredinol y waled</translation>
@@ -301,14 +293,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Newid cyfrinymadrodd...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Cyfeiriadau anfon...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Cyfeiriadau derbyn...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Agor &amp;URI...</translation>
@@ -357,10 +341,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Waled</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Anfon</translation>
@@ -461,6 +441,10 @@
         <source>Up to date</source>
         <translation>Cyfamserol</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Ffenestr</translation>
+    </message>
     <message>
         <source>Connecting to peers...</source>
         <translation>Cysylltu efo cyfoedion...</translation>
@@ -1006,6 +990,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
