@@ -3,24 +3,16 @@
     <name>AddressBookPage</name>
     <message>
         <source>Right-click to edit address or label</source>
-        <translation>Rechtsklick um Adresse oder Etikett zu bearbeiten</translation>
+        <translation>&lt;br&gt;</translation>
     </message>
     <message>
         <source>Create a new address</source>
         <translation>Eine neue Adresse erstellen</translation>
     </message>
-    <message>
-        <source>&amp;New</source>
-        <translation>&amp;Neu</translation>
-    </message>
     <message>
         <source>Copy the currently selected address to the system clipboard</source>
         <translation>Aktive Adresse in die Zwischenablage kopieren</translation>
     </message>
-    <message>
-        <source>&amp;Copy</source>
-        <translation>&amp;Kopieren</translation>
-    </message>
     <message>
         <source>C&amp;lose</source>
         <translation>Schliessen</translation>
@@ -37,10 +29,6 @@
         <source>&amp;Export</source>
         <translation>&amp;Exportieren</translation>
     </message>
-    <message>
-        <source>&amp;Delete</source>
-        <translation>&amp;Löschen</translation>
-    </message>
     <message>
         <source>Choose the address to send coins to</source>
         <translation>Wähle die Empfängeradresse</translation>
@@ -53,34 +41,10 @@
         <source>C&amp;hoose</source>
         <translation>Auswählen</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation>Sendeadressen</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation>Empfangsadressen</translation>
-    </message>
-    <message>
-        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
-        <translation>Dies sind Ihre Litecoin-Adressen zum Senden von Zahlungen. Überprüfen Sie immer die Menge und die Empfangsadresse, bevor Sie Litecoins senden.</translation>
-    </message>
     <message>
         <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
         <translation>Dies sind Ihre Litecoin-Adressen für den Empfang von Zahlungen. Es wird empfohlen, für jede Transaktion eine neue Empfangsadresse zu verwenden.</translation>
     </message>
-    <message>
-        <source>&amp;Copy Address</source>
-        <translation>&amp;Kopiere Adresse</translation>
-    </message>
-    <message>
-        <source>Copy &amp;Label</source>
-        <translation>Kopiere &amp;Etikett</translation>
-    </message>
-    <message>
-        <source>&amp;Edit</source>
-        <translation>&amp;Bearbeiten</translation>
-    </message>
     <message>
         <source>Export Address List</source>
         <translation>Export Adressliste</translation>
@@ -100,10 +64,6 @@
         <source>Label</source>
         <translation>Etikett</translation>
     </message>
-    <message>
-        <source>Address</source>
-        <translation>Adresse</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(kein Etikett)</translation>
@@ -115,26 +75,18 @@
         <source>Passphrase Dialog</source>
         <translation>Passwort Dialog</translation>
     </message>
-    <message>
-        <source>Enter passphrase</source>
-        <translation>Passwort eingeben</translation>
-    </message>
     <message>
         <source>New passphrase</source>
         <translation>Neues Passwort</translation>
     </message>
     <message>
-        <source>Repeat new passphrase</source>
-        <translation>Neues Passwort wiederholen</translation>
+        <source>Show password</source>
+        <translation>Passwort anzeigen</translation>
     </message>
     <message>
         <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
         <translation>Geben Sie das neue Passwort Ihrer digitalen Geldbörse ein.&lt;br/&gt;Verwenden Sie bitte ein Passwort bestehend aus &lt;b&gt;zehn oder mehr zufälligen Zeichen&lt;/b&gt;, oder aus &lt;b&gt;acht oder mehr Wörtern&lt;/b&gt;.</translation>
     </message>
-    <message>
-        <source>Encrypt wallet</source>
-        <translation>Brieftasche verschlüsseln</translation>
-    </message>
     <message>
         <source>This operation needs your wallet passphrase to unlock the wallet.</source>
         <translation>Diese Aktion benötigt ihr Passwort zum entsperren der Wallet.</translation>
@@ -147,10 +99,6 @@
         <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
         <translation>Diese Operation benötigt Ihr Wallet-Passwort zum entschlüsseln der Wallet.</translation>
     </message>
-    <message>
-        <source>Decrypt wallet</source>
-        <translation>Brieftasche entschlüsseln</translation>
-    </message>
     <message>
         <source>Change passphrase</source>
         <translation>Passwort ändern</translation>
@@ -159,18 +107,6 @@
         <source>Enter the old passphrase and new passphrase to the wallet.</source>
         <translation>Geben Sie das alte und neue Passwort Ihrer Wallet ein.</translation>
     </message>
-    <message>
-        <source>Confirm wallet encryption</source>
-        <translation>Brieftaschenverschlüsselung bestätigen</translation>
-    </message>
-    <message>
-        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
-        <translation>Achtung: Wenn Sie Ihre Wallet verschlüsseln und das Passwort verlieren, gehen &lt;b&gt;alle Ihre Litecoins verloren&lt;/b&gt;!</translation>
-    </message>
-    <message>
-        <source>Are you sure you wish to encrypt your wallet?</source>
-        <translation>Möchten Sie Ihre Wallet wirklich verschlüsseln?</translation>
-    </message>
     <message>
         <source>Wallet encrypted</source>
         <translation>Brieftasche verschlüsselt</translation>
@@ -179,10 +115,6 @@
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>WICHTIG: Alle früheren Sicherungen, die Sie von Ihrer Wallet-Datei gemacht haben, sollten durch die neu erzeugte, verschlüsselte Wallet-Datei ersetzt werden. Sobald Sie die neue, verschlüsselte Wallet verwenden, werden frühere Sicherungen der unverschlüsselten Wallet-Datei aus Sicherheitsgründen nutzlos.</translation>
     </message>
-    <message>
-        <source>Wallet encryption failed</source>
-        <translation>Brieftaschenverschlüsselung fehlgeschlagen</translation>
-    </message>
     <message>
         <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
         <translation>Die Wallet-Verschlüsselung ist aufgrund eines internen Fehlers fehlgeschlagen. Ihre Wallet wurde nicht verschlüsselt.</translation>
@@ -191,14 +123,6 @@
         <source>The supplied passphrases do not match.</source>
         <translation>Die eingegebenen Passwörter stimmen nicht überein.</translation>
     </message>
-    <message>
-        <source>Wallet unlock failed</source>
-        <translation>Brieftasche öffnen fehlgeschlagen</translation>
-    </message>
-    <message>
-        <source>The passphrase entered for the wallet decryption was incorrect.</source>
-        <translation>Inkorrektes Passwort um die Brieftasche zu entschlüsseln</translation>
-    </message>
     <message>
         <source>Wallet decryption failed</source>
         <translation>Brieftasche entschlüsseln fehlgeschlagen</translation>
@@ -207,36 +131,20 @@
         <source>Wallet passphrase was successfully changed.</source>
         <translation>Brieftaschen Passwort erfolgreich geändert</translation>
     </message>
-    <message>
-        <source>Warning: The Caps Lock key is on!</source>
-        <translation>Achtung: Die Umschalttaste ist eingeschaltet!</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>BanTableModel</name>
     <message>
         <source>IP/Netmask</source>
         <translation>IP/Netzmaske</translation>
     </message>
-    <message>
-        <source>Banned Until</source>
-        <translation>Gesperrt bis</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>BitcoinGUI</name>
-    <message>
-        <source>Synchronizing with network...</source>
-        <translation>Über das Netzwerk abgleichen</translation>
-    </message>
     <message>
         <source>&amp;Overview</source>
         <translation>&amp;Übersicht</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Knoten</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Generelle Übersicht der Brieftasche </translation>
@@ -245,10 +153,6 @@
         <source>&amp;Transactions</source>
         <translation>&amp;Transaktionen</translation>
     </message>
-    <message>
-        <source>Browse transaction history</source>
-        <translation>Zeige Transaktionsverlauf</translation>
-    </message>
     <message>
         <source>E&amp;xit</source>
         <translation>Beenden</translation>
@@ -257,18 +161,6 @@
         <source>Quit application</source>
         <translation>Programm beenden</translation>
     </message>
-    <message>
-        <source>&amp;About %1</source>
-        <translation>&amp;Über %1</translation>
-    </message>
-    <message>
-        <source>Show information about %1</source>
-        <translation>Zeige Informationen zu %1</translation>
-    </message>
-    <message>
-        <source>About &amp;Qt</source>
-        <translation>Über &amp;Qt</translation>
-    </message>
     <message>
         <source>Show information about Qt</source>
         <translation>Informationen über Qt anzeigen</translation>
@@ -289,18 +181,6 @@
         <source>&amp;Backup Wallet...</source>
         <translation>Sicherungskopie der Brieftasche...</translation>
     </message>
-    <message>
-        <source>&amp;Change Passphrase...</source>
-        <translation>&amp;Passwort ändern...</translation>
-    </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Adressen senden...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Adressen empfangen...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Öffne &amp;URI...</translation>
@@ -313,10 +193,6 @@
         <source>Network activity disabled.</source>
         <translation>Netzwerkaktivität wurde deaktiviert.</translation>
     </message>
-    <message>
-        <source>Click to enable network activity again.</source>
-        <translation>Klicken Sie, um die Netzwerkaktivität wieder zu aktivieren.</translation>
-    </message>
     <message>
         <source>Syncing Headers (%1%)...</source>
         <translation>Synchronisiere Header (%1%)...</translation>
@@ -325,10 +201,6 @@
         <source>Reindexing blocks on disk...</source>
         <translation>Reindexiere Blöcke auf dem Datenträger...</translation>
     </message>
-    <message>
-        <source>Send coins to a Litecoin address</source>
-        <translation>Coins an eine Litecoin-Adresse senden</translation>
-    </message>
     <message>
         <source>Backup wallet to another location</source>
         <translation>Wallet an einen anderen Ort sichern</translation>
@@ -353,10 +225,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Brieftasche</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Senden</translation>
@@ -401,10 +269,6 @@
         <source>Tabs toolbar</source>
         <translation>Registerkarten-Symbolleiste</translation>
     </message>
-    <message>
-        <source>Show the list of used sending addresses and labels</source>
-        <translation>Liste der benutzten Sendeadressen und -etiketten</translation>
-    </message>
     <message>
         <source>Show the list of used receiving addresses and labels</source>
         <translation>Zeige Liste der benutzten Empfangsadressen und -etiketten</translation>
@@ -413,14 +277,6 @@
         <source>Indexing blocks on disk...</source>
         <translation>Indexiere Blöcke auf dem Datenträger...</translation>
     </message>
-    <message>
-        <source>Processing blocks on disk...</source>
-        <translation>Verarbeite Blöcke auf dem Datenträger...</translation>
-    </message>
-    <message>
-        <source>%1 behind</source>
-        <translation>%1 im Rückstand</translation>
-    </message>
     <message>
         <source>Transactions after this will not yet be visible.</source>
         <translation>Transaktionen danach sind noch nicht sichtbar.</translation>
@@ -433,10 +289,6 @@
         <source>Warning</source>
         <translation>Achtung</translation>
     </message>
-    <message>
-        <source>Information</source>
-        <translation>Information</translation>
-    </message>
     <message>
         <source>Up to date</source>
         <translation>Auf dem neuesten Stand</translation>
@@ -478,14 +330,6 @@
         <source>Bytes:</source>
         <translation>Byte:</translation>
     </message>
-    <message>
-        <source>Amount:</source>
-        <translation>Betrag:</translation>
-    </message>
-    <message>
-        <source>Fee:</source>
-        <translation>Gebühr:</translation>
-    </message>
     <message>
         <source>Dust:</source>
         <translation>Dust:</translation>
@@ -506,34 +350,14 @@
         <source>Confirmations</source>
         <translation>Bestätigungen</translation>
     </message>
-    <message>
-        <source>Confirmed</source>
-        <translation>Bestätigt</translation>
-    </message>
-    <message>
-        <source>Copy address</source>
-        <translation>Adresse kopieren</translation>
-    </message>
     <message>
         <source>Copy label</source>
         <translation>Etikett kopieren</translation>
     </message>
-    <message>
-        <source>Copy amount</source>
-        <translation>Betrag kopieren</translation>
-    </message>
     <message>
         <source>Copy transaction ID</source>
         <translation>Transaktions ID kopieren</translation>
     </message>
-    <message>
-        <source>Copy quantity</source>
-        <translation>Menge kopieren</translation>
-    </message>
-    <message>
-        <source>yes</source>
-        <translation>Ja</translation>
-    </message>
     <message>
         <source>no</source>
         <translation>Nein</translation>
@@ -557,10 +381,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adresse</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Neue Empfangsadresse</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Neue Sendeadresse</translation>
@@ -609,20 +429,12 @@
         <source>Form</source>
         <translation>Formular</translation>
     </message>
-    <message>
-        <source>Unknown...</source>
-        <translation>Unbekannt...</translation>
-    </message>
     </context>
 <context>
     <name>OpenURIDialog</name>
     </context>
 <context>
     <name>OptionsDialog</name>
-    <message>
-        <source>Error</source>
-        <translation>Fehler</translation>
-    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -694,6 +506,10 @@
         <source>Label</source>
         <translation>Etikett</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Brieftasche</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -705,10 +521,6 @@
         <source>Label</source>
         <translation>Etikett</translation>
     </message>
-    <message>
-        <source>(no label)</source>
-        <translation>(kein Etikett)</translation>
-    </message>
     </context>
 <context>
     <name>SendCoinsDialog</name>
@@ -720,10 +532,6 @@
         <source>Bytes:</source>
         <translation>Byte:</translation>
     </message>
-    <message>
-        <source>Amount:</source>
-        <translation>Betrag:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Gebühr:</translation>
@@ -740,10 +548,6 @@
         <source>Copy quantity</source>
         <translation>Menge kopieren</translation>
     </message>
-    <message>
-        <source>Copy amount</source>
-        <translation>Betrag kopieren</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(kein Etikett)</translation>
@@ -814,10 +618,6 @@
         <source>Copy transaction ID</source>
         <translation>Transaktions ID kopieren</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Komma getrenntes Dokument (*.csv)</translation>
-    </message>
     <message>
         <source>Confirmed</source>
         <translation>Bestätigt</translation>
@@ -842,6 +642,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
@@ -850,14 +653,6 @@
     </context>
 <context>
     <name>WalletView</name>
-    <message>
-        <source>&amp;Export</source>
-        <translation>&amp;Exportieren</translation>
-    </message>
-    <message>
-        <source>Export the data in the current tab to a file</source>
-        <translation>Daten des aktiven Fensters exportieren</translation>
-    </message>
     <message>
         <source>Backup Failed</source>
         <translation>Sicherung fehlgeschlagen</translation>
@@ -869,34 +664,14 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Optionen:</translation>
-    </message>
-    <message>
-        <source>Information</source>
-        <translation>Information</translation>
-    </message>
-    <message>
-        <source>Warning</source>
-        <translation>Achtung</translation>
-    </message>
     <message>
         <source>Starting network threads...</source>
         <translation>Starte Netzwerk-Threads...</translation>
     </message>
-    <message>
-        <source>This is the minimum transaction fee you pay on every transaction.</source>
-        <translation>Das ist die Mindestgebühr für jede Transaktion</translation>
-    </message>
     <message>
         <source>This is the transaction fee you will pay if you send a transaction.</source>
         <translation>Das ist die Gebühr für die Überweisung</translation>
     </message>
-    <message>
-        <source>Transaction amounts must not be negative</source>
-        <translation>Überweisungsbetrag kann nicht negativ sein</translation>
-    </message>
     <message>
         <source>Transaction must have at least one recipient</source>
         <translation>Überweisung muss mindestens einen Empfänger haben </translation>
