@@ -242,10 +242,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>&amp;Overview</source>
         <translation>&amp;Visión de conjunto</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Nodo</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Mostrar vista general de la billetera</translation>
@@ -290,14 +286,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Cambiar contraseña...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Enviando Direcciones...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Recibiendo Direcciones...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Abrir &amp;URL...</translation>
@@ -346,10 +334,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Billetera</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Enviar</translation>
@@ -442,6 +426,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Up to date</source>
         <translation>A hoy</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>Ventana</translation>
+    </message>
     <message>
         <source>Connecting to peers...</source>
         <translation>Conectando con sus pares ...</translation>
@@ -818,10 +806,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Size of &amp;database cache</source>
         <translation>Tamaño de la memoria caché de la base de datos</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>Cantidad de secuencias de comandos y verificación</translation>
@@ -850,10 +834,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
         <translation>Minimice en lugar de salir de la aplicación cuando la ventana esté cerrada. Cuando esta opción está habilitada, la aplicación se cerrará solo después de seleccionar Salir en el menú.</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>Opciones de línea de comando activas que anulan las opciones anteriores:</translation>
-    </message>
     <message>
         <source>Open Configuration File</source>
         <translation>Abrir archivo de configuración</translation>
@@ -1878,6 +1858,9 @@ Tarifa de copia</translation>
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
