@@ -321,10 +321,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Rahakott</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Saada</translation>
@@ -425,6 +421,10 @@
         <source>Up to date</source>
         <translation>Ajakohane</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Aken</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 klient</translation>
@@ -715,10 +715,6 @@
         <source>&amp;Main</source>
         <translation>&amp;Peamine</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>Taasta kõik klientprogrammi seadete vaikeväärtused.</translation>
@@ -1878,6 +1874,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
