@@ -133,10 +133,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Rahakott</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Saada</translation>
@@ -285,10 +281,6 @@
         <source>Options</source>
         <translation>Valikud</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>&amp;Network</source>
         <translation>&amp;Võrk</translation>
@@ -736,6 +728,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
