@@ -3,7 +3,7 @@
     <name>AddressBookPage</name>
     <message>
         <source>Right-click to edit address or label</source>
-        <translation>Klikatu eskuinean helbidea edo etiketa aldatzeko</translation>
+        <translation>Klikatu eskuinarekin helbidea edo etiketa aldatzeko</translation>
     </message>
     <message>
         <source>Create a new address</source>
@@ -135,6 +135,14 @@
         <source>Repeat new passphrase</source>
         <translation>Pasahitz berria errepiikatu</translation>
     </message>
+    <message>
+        <source>Show password</source>
+        <translation>Erakutsi pasahitza</translation>
+    </message>
+    <message>
+        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
+        <translation>Sartu pasaesaldi bat diru-zorrorako. Mesedez erabili ausazko hamar edo gehiago karaktere edo zortzi edo gehiago hitz.</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Diruzorroa enkriptatu</translation>
@@ -249,10 +257,6 @@
         <source>&amp;Options...</source>
         <translation>&amp;Aukerak...</translation>
     </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Helbideak jasotzen...</translation>
-    </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Diruzorroa enkriptatzeko erabilitako pasahitza aldatu</translation>
@@ -273,6 +277,10 @@
         <source>Tabs toolbar</source>
         <translation>Fitxen tresna-barra</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Akatsa</translation>
+    </message>
     <message>
         <source>Up to date</source>
         <translation>Eguneratua</translation>
@@ -368,6 +376,10 @@
     </context>
 <context>
     <name>Intro</name>
+    <message>
+        <source>Error</source>
+        <translation>Akatsa</translation>
+    </message>
     </context>
 <context>
     <name>ModalOverlay</name>
@@ -385,6 +397,10 @@
         <source>Options</source>
         <translation>Aukerak</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Akatsa</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -784,6 +800,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
@@ -807,6 +826,10 @@
     </context>
 <context>
     <name>bitcoin-core</name>
+    <message>
+        <source>Loading wallet...</source>
+        <translation>Diru-zorroa kargatzen</translation>
+    </message>
     <message>
         <source>Rescanning...</source>
         <translation>Birbilatzen...</translation>
@@ -815,5 +838,9 @@
         <source>Done loading</source>
         <translation>Zamaketa amaitua</translation>
     </message>
-    </context>
+    <message>
+        <source>Error</source>
+        <translation>Akatsa</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
