@@ -125,10 +125,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Cambiar contrasinal...</translation>
     </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Direccións para recibir</translation>
-    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>Reindexando bloques no disco...</translation>
@@ -161,10 +157,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Moedeiro</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Enviar</translation>
@@ -257,6 +249,10 @@
         <source>Up to date</source>
         <translation>Actualizado</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Xanela</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>Poñendo ao día...</translation>
@@ -988,6 +984,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
