@@ -183,10 +183,6 @@
         <source>Wallet encrypted</source>
         <translation>Tárca titkosítva</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 Most az ablak bezáródik, amíg befejeződik a titkosítási folyamat. Kérem vegye figyelembe, hogy a pénztárca titkosítása nem jelenti a litecoinjai teljes körű védelmét, a számítógépét esetlegesen megfertőző kártékony programoktól.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>FONTOS: A régebbi biztonsági mentéseket frissítse az új, titkosított pénztárca fájllal. Biztonsági okokból, a korábbi titkosítatlan pénztárca fájlok nem használhatóak az új titkosított pénztárcával.</translation>
@@ -249,10 +245,6 @@
         <source>&amp;Overview</source>
         <translation>Á&amp;ttekintés</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Csomópont</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>A pénztárca általános áttekintése</translation>
@@ -309,14 +301,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Jelszóhalmaz megváltoztatása</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Címek küldése</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Címek &amp;fogadása</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>&amp;URI... Megnyitása</translation>
@@ -369,10 +353,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Tárca</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>Küldé&amp;s</translation>
@@ -485,6 +465,10 @@
         <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
         <translation>Mutassa a %1 súgó üzenetet a lehetséges Litecoin parancssori beállítások listájáért</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Ablak</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 kliens</translation>
@@ -729,10 +713,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Cím</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Új fogadási cím</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Új küldési cím</translation>
@@ -749,10 +729,6 @@
         <source>The entered address "%1" is not a valid Litecoin address.</source>
         <translation>A megadott cím"%1" nem egy érvényes Litecoin cím.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>A megadott cím "%1" már szerepel a címlistában.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>A tárca feloldása nem lehetséges</translation>
@@ -803,42 +779,6 @@
         <source>Command-line options</source>
         <translation>Parancssor beállításai</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Használat:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>parancssor beállításai</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>Felhasználói felület beállításai</translation>
-    </message>
-    <message>
-        <source>Choose data directory on startup (default: %u)</source>
-        <translation>Adja meg az indításkor használt adat könyvtárat (alapbeállítás: %u)</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Nyelv beállítása, például "de_DE" (alaphelyzetben: a helyi rendszer nyelve)</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Indítás rejtett ablakkal</translation>
-    </message>
-    <message>
-        <source>Set SSL root certificates for payment request (default: -system-)</source>
-        <translation>A fizetési kérelmek SSL tanúsítványainak beállítása (alaphelyzetben: -a rendszer beállításai szerint-)</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>Mutassa a kezdő képet indításkor (alaphelyzetben: %u)</translation>
-    </message>
-    <message>
-        <source>Reset all settings changed in the GUI</source>
-        <translation>A grafikus felület összes megváltoztatott beállításának a visszaállítása</translation>
-    </message>
 </context>
 <context>
     <name>Intro</name>
@@ -953,11 +893,7 @@
         <source>Hide</source>
         <translation>Elrejtés</translation>
     </message>
-    <message>
-        <source>Unknown. Syncing Headers (%1)...</source>
-        <translation>Ismeretlen. Fejlécek szinkronizálása (%1)...</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     <message>
@@ -1003,10 +939,6 @@
         <source>Size of &amp;database cache</source>
         <translation>Az &amp;adatbázis cache mérete</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>A szkript &amp;igazolási szálak száma</translation>
@@ -1035,10 +967,6 @@
         <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
         <translation>Harmadik féltől származó URL-ek (pl. egy blokk felfedező) amelyek a tranzakciós fülön jelennek meg mint a környezetérzékeny menü tételei. %s az URL-ben helyettesítve a tranzakciós hash-el. Több URL esetén, függőleges vonal választja el őket.</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>Aktív parancssori beállítások, melyek felülírják a fenti beállításokat:</translation>
-    </message>
     <message>
         <source>Open the %1 configuration file from the working directory.</source>
         <translation>A %1 konfigurációs fájl megnyitása a munkakönyvtárból.</translation>
@@ -1095,6 +1023,10 @@
         <source>Accept connections from outside.</source>
         <translation>Kívülről érkező kapcsolatok fogadása.</translation>
     </message>
+    <message>
+        <source>Allow incomin&amp;g connections</source>
+        <translation>&amp;Bejövő kapcsolatok engedélyezése</translation>
+    </message>
     <message>
         <source>Connect to the Litecoin network through a SOCKS5 proxy.</source>
         <translation>Csatlakozás a Litecoin hálózathoz SOCKS5 proxy használatával.</translation>
@@ -1175,6 +1107,10 @@
         <source>Whether to show coin control features or not.</source>
         <translation>Mutassa a pénzküldés beállításait vagy ne.</translation>
     </message>
+    <message>
+        <source>&amp;Third party transaction URLs</source>
+        <translation>&amp;Harmadik féltől származó tranzakciós URL-ek</translation>
+    </message>
     <message>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
@@ -1337,6 +1273,10 @@
         <source>Payment request rejected</source>
         <translation>Fizetési kérelem elutasítva</translation>
     </message>
+    <message>
+        <source>Payment request network doesn't match client network.</source>
+        <translation>A fizetési kérelem hálózat nem egyezik a kliens hálózatával.</translation>
+    </message>
     <message>
         <source>Payment request expired.</source>
         <translation>Fizetési kérelem lejárt</translation>
@@ -1349,6 +1289,10 @@
         <source>Invalid payment request.</source>
         <translation>Érvénytelen fizetési kérelem</translation>
     </message>
+    <message>
+        <source>Requested payment amount of %1 is too small (considered dust).</source>
+        <translation>A %1 fizetésre kért összege túl kevés (porszemnek minősül).</translation>
+    </message>
     <message>
         <source>Refund from %1</source>
         <translation>Visszatérítés innen: %1</translation>
@@ -1357,10 +1301,18 @@
         <source>Payment request %1 is too large (%2 bytes, allowed %3 bytes).</source>
         <translation>A %1 fizetési kérelem túl nagy (%2 bájt, megengedett: %3 bájt).</translation>
     </message>
+    <message>
+        <source>Error communicating with %1: %2</source>
+        <translation>Hiba a kommunikáció során %1 -el: %2</translation>
+    </message>
     <message>
         <source>Payment request cannot be parsed!</source>
         <translation>A fizetési kérelem nem dolgozható fel!</translation>
     </message>
+    <message>
+        <source>Bad response from server %1</source>
+        <translation>Rossz válasz a szervertől %1</translation>
+    </message>
     <message>
         <source>Network request error</source>
         <translation>Hálózati hiba történt</translation>
@@ -1372,10 +1324,18 @@
 </context>
 <context>
     <name>PeerTableModel</name>
+    <message>
+        <source>User Agent</source>
+        <translation>User Agent</translation>
+    </message>
     <message>
         <source>Node/Service</source>
         <translation>Csomópont/Szolgáltatás</translation>
     </message>
+    <message>
+        <source>NodeId</source>
+        <translation>Csomópont azonosító</translation>
+    </message>
     <message>
         <source>Ping</source>
         <translation>Ping</translation>
@@ -1471,6 +1431,10 @@
         <source>%1 GB</source>
         <translation>%1 GB</translation>
     </message>
+    <message>
+        <source>%1 didn't yet exit safely...</source>
+        <translation>%1 még nem lépett ki biztonságosan...</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>ismeretlen</translation>
@@ -1478,6 +1442,10 @@
 </context>
 <context>
     <name>QObject::QObject</name>
+    <message>
+        <source>Error: Specified data directory "%1" does not exist.</source>
+        <translation>Hiba: A megadott "%1" adatkönyvtár nem létezik.</translation>
+    </message>
     <message>
         <source>Error: %1</source>
         <translation>Hiba: %1</translation>
@@ -1556,6 +1524,10 @@
         <source>Current number of blocks</source>
         <translation>Blokkok aktuális száma</translation>
     </message>
+    <message>
+        <source>Memory Pool</source>
+        <translation>Memória Halom</translation>
+    </message>
     <message>
         <source>Current number of transactions</source>
         <translation>Tranzakciók pillanatnyi száma</translation>
@@ -1576,6 +1548,18 @@
         <source>Sent</source>
         <translation>Elküldve</translation>
     </message>
+    <message>
+        <source>&amp;Peers</source>
+        <translation>&amp;Peer-ek</translation>
+    </message>
+    <message>
+        <source>Banned peers</source>
+        <translation>Letiltott peer-ek</translation>
+    </message>
+    <message>
+        <source>Select a peer to view detailed information.</source>
+        <translation>Peer kijelölése a részletes információkért</translation>
+    </message>
     <message>
         <source>Whitelisted</source>
         <translation>Engedélyezett</translation>
@@ -1600,6 +1584,14 @@
         <source>Synced Blocks</source>
         <translation>Szinkronizált blokkok</translation>
     </message>
+    <message>
+        <source>User Agent</source>
+        <translation>User Agent</translation>
+    </message>
+    <message>
+        <source>Open the %1 debug log file from the current data directory. This can take a few seconds for large log files.</source>
+        <translation>A %1 hibakeresési naplófájl megnyitása a jelenlegi könyvtárból. Ez néhány másodpercig eltarthat nagyobb naplófájlok esetén.</translation>
+    </message>
     <message>
         <source>Decrease font size</source>
         <translation>Betűméret csökkentése</translation>
@@ -1624,10 +1616,26 @@
         <source>Last Receive</source>
         <translation>Utolsó fogadás</translation>
     </message>
+    <message>
+        <source>Ping Time</source>
+        <translation>Ping idő</translation>
+    </message>
+    <message>
+        <source>The duration of a currently outstanding ping.</source>
+        <translation>A jelenlegi kiváló ping időtartama.</translation>
+    </message>
     <message>
         <source>Ping Wait</source>
         <translation>Várakozás ping-re</translation>
     </message>
+    <message>
+        <source>Min Ping</source>
+        <translation>Minimum Ping</translation>
+    </message>
+    <message>
+        <source>Time Offset</source>
+        <translation>Idő Eltolódás</translation>
+    </message>
     <message>
         <source>Last block time</source>
         <translation>Utolsó blokk ideje</translation>
@@ -1656,6 +1664,10 @@
         <source>Out:</source>
         <translation>Ki:</translation>
     </message>
+    <message>
+        <source>Debug log file</source>
+        <translation>Hibakeresési napló fájl</translation>
+    </message>
     <message>
         <source>Clear console</source>
         <translation>Konzol ürítése</translation>
@@ -1680,6 +1692,18 @@
         <source>&amp;Disconnect</source>
         <translation>&amp;Szétkapcsol</translation>
     </message>
+    <message>
+        <source>Ban for</source>
+        <translation>Tiltás oka</translation>
+    </message>
+    <message>
+        <source>&amp;Unban</source>
+        <translation>&amp;Tiltás feloldása</translation>
+    </message>
+    <message>
+        <source>Welcome to the %1 RPC console.</source>
+        <translation>Üdv az %1 RPC konzoljában.</translation>
+    </message>
     <message>
         <source>Use up and down arrows to navigate history, and %1 to clear screen.</source>
         <translation>Az előzmények közötti navigálásához használd a fel és le nyilakat, és %1-t a képernyő törléséhez.</translation>
@@ -1688,6 +1712,14 @@
         <source>Type %1 for an overview of available commands.</source>
         <translation>Írja be a %1 parancsot az elérhető utasítások áttekintéséhez.</translation>
     </message>
+    <message>
+        <source>WARNING: Scammers have been active, telling users to type commands here, stealing their wallet contents. Do not use this console without fully understanding the ramifications of a command.</source>
+        <translation>FIGYELEM: Csalók megpróbálnak felhasználókat rávenni, hogy parancsokat írjanak be ide, és ellopják a tárca tartalmát. Ne használja ezt a konzolt anélkül, hogy teljesen megértené egy parancs kiadásának a következményeit.</translation>
+    </message>
+    <message>
+        <source>Network activity disabled</source>
+        <translation>Hálózat aktivitása letiltva</translation>
+    </message>
     <message>
         <source>(node id: %1)</source>
         <translation>(csomópont azonosító: %1)</translation>
@@ -1747,6 +1779,10 @@
         <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
         <translation>Használja ezt az űrlapot fizetések kérésére. Minden mező &lt;b&gt;opcionális&lt;/b&gt;.</translation>
     </message>
+    <message>
+        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
+        <translation>Egy opcionálisan kérhető összeg. Hagyja üresen, vagy írjon be nullát, ha nem kívánja használni.</translation>
+    </message>
     <message>
         <source>Clear all fields of the form.</source>
         <translation>Az űrlap összes mezőjének törlése</translation>
@@ -1755,10 +1791,26 @@
         <source>Clear</source>
         <translation>Törlés</translation>
     </message>
+    <message>
+        <source>Requested payments history</source>
+        <translation>A kért kifizetések előzménye</translation>
+    </message>
+    <message>
+        <source>&amp;Request payment</source>
+        <translation>&amp;Fizetési kérelem</translation>
+    </message>
+    <message>
+        <source>Show the selected request (does the same as double clicking an entry)</source>
+        <translation>Mutassa meg a kiválasztott kérelmet (ugyanaz, mint a duplaklikk)</translation>
+    </message>
     <message>
         <source>Show</source>
         <translation>Megmutatás</translation>
     </message>
+    <message>
+        <source>Remove the selected entries from the list</source>
+        <translation>A kijelölt elemek törlése a listáról</translation>
+    </message>
     <message>
         <source>Remove</source>
         <translation>Eltávolítás</translation>
@@ -1786,10 +1838,22 @@
         <source>QR Code</source>
         <translation>QR-kód</translation>
     </message>
+    <message>
+        <source>Copy &amp;URI</source>
+        <translation>&amp;URI másolása</translation>
+    </message>
+    <message>
+        <source>Copy &amp;Address</source>
+        <translation>&amp;Cím másolása</translation>
+    </message>
     <message>
         <source>&amp;Save Image...</source>
         <translation>Kép &amp;mentése</translation>
     </message>
+    <message>
+        <source>Request payment to %1</source>
+        <translation>Fizetési kérelem tőle: %1</translation>
+    </message>
     <message>
         <source>Payment information</source>
         <translation>Fizetési információ</translation>
@@ -1814,7 +1878,19 @@
         <source>Message</source>
         <translation>Üzenet</translation>
     </message>
-    </context>
+    <message>
+        <source>Wallet</source>
+        <translation>Tárca</translation>
+    </message>
+    <message>
+        <source>Resulting URI too long, try to reduce the text for label / message.</source>
+        <translation>A keletkezett URI túl hosszú, próbálja meg csökkenteni a cimke / üzenet szövegének méretét.</translation>
+    </message>
+    <message>
+        <source>Error encoding URI into QR Code.</source>
+        <translation>Hiba lépett fel az URI QR kóddá alakításakor.</translation>
+    </message>
+</context>
 <context>
     <name>RecentRequestsTableModel</name>
     <message>
@@ -1837,13 +1913,37 @@
         <source>(no message)</source>
         <translation>(nincs üzenet)</translation>
     </message>
-    </context>
+    <message>
+        <source>(no amount requested)</source>
+        <translation>(nem kért összeget)</translation>
+    </message>
+    <message>
+        <source>Requested</source>
+        <translation>Kért</translation>
+    </message>
+</context>
 <context>
     <name>SendCoinsDialog</name>
+    <message>
+        <source>Send Coins</source>
+        <translation>Érmék küldése</translation>
+    </message>
+    <message>
+        <source>Coin Control Features</source>
+        <translation>Pénzküldés beállításai</translation>
+    </message>
+    <message>
+        <source>Inputs...</source>
+        <translation>Bemenetek...</translation>
+    </message>
     <message>
         <source>automatically selected</source>
         <translation>automatikusan kiválasztva</translation>
     </message>
+    <message>
+        <source>Insufficient funds!</source>
+        <translation>Fedezethiány!</translation>
+    </message>
     <message>
         <source>Quantity:</source>
         <translation>Mennyiség:</translation>
@@ -1868,6 +1968,14 @@
         <source>Change:</source>
         <translation>Visszajáró:</translation>
     </message>
+    <message>
+        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
+        <translation>Ha ezt a beállítást engedélyezi, de a visszajáró cím érvénytelen, a visszajáró egy újonnan generált címre lesz küldve.</translation>
+    </message>
+    <message>
+        <source>Custom change address</source>
+        <translation>Egyedi visszajáró cím</translation>
+    </message>
     <message>
         <source>Transaction Fee:</source>
         <translation>Tranzakciós díj:</translation>
@@ -1876,6 +1984,10 @@
         <source>Choose...</source>
         <translation>Választás...</translation>
     </message>
+    <message>
+        <source>Warning: Fee estimation is currently not possible.</source>
+        <translation>Figyelem: A hozzávetőleges díjszámítás jelenleg nem lehetséges.</translation>
+    </message>
     <message>
         <source>per kilobyte</source>
         <translation>kilobájtonként</translation>
@@ -1888,6 +2000,10 @@
         <source>Recommended:</source>
         <translation>Ajánlott:</translation>
     </message>
+    <message>
+        <source>Custom:</source>
+        <translation>Egyedi:</translation>
+    </message>
     <message>
         <source>Send to multiple recipients at once</source>
         <translation>Küldés egyszerre több címzettnek</translation>
@@ -1900,10 +2016,22 @@
         <source>Dust:</source>
         <translation>Porszem:</translation>
     </message>
+    <message>
+        <source>Confirmation time target:</source>
+        <translation>Megerősítési idő cél:</translation>
+    </message>
+    <message>
+        <source>Clear &amp;All</source>
+        <translation>&amp;Mindent töröl</translation>
+    </message>
     <message>
         <source>Balance:</source>
         <translation>Egyenleg:</translation>
     </message>
+    <message>
+        <source>S&amp;end</source>
+        <translation>&amp;Küldés</translation>
+    </message>
     <message>
         <source>Copy quantity</source>
         <translation>Mennyiség másolása</translation>
@@ -1940,10 +2068,22 @@
         <source>or</source>
         <translation>vagy</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Tranzakciós díj</translation>
+    </message>
     <message>
         <source>The amount to pay must be larger than 0.</source>
         <translation>Az összegnek nagyobbnak kell lennie, mint 0.</translation>
     </message>
+    <message>
+        <source>The amount exceeds your balance.</source>
+        <translation>Az összeg túlhaladja az egyenleged.</translation>
+    </message>
+    <message>
+        <source>Transaction creation failed!</source>
+        <translation>Tranzakció készítése sikertelen!</translation>
+    </message>
     <message>
         <source>Payment request expired.</source>
         <translation>Fizetési kérelem lejárt</translation>
@@ -1952,6 +2092,10 @@
         <source>Warning: Invalid Litecoin address</source>
         <translation>Figyelem: érvénytelen Litecoin cím</translation>
     </message>
+    <message>
+        <source>Confirm custom change address</source>
+        <translation>Egyedi visszajáró cím megerősítése</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(nincs címke)</translation>
@@ -1959,6 +2103,10 @@
 </context>
 <context>
     <name>SendCoinsEntry</name>
+    <message>
+        <source>A&amp;mount:</source>
+        <translation>&amp;Összeg:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Címke:</translation>
@@ -1967,6 +2115,10 @@
         <source>Choose previously used address</source>
         <translation>Válasszon a korábban használt címek közül</translation>
     </message>
+    <message>
+        <source>This is a normal payment.</source>
+        <translation>Ez egy normális fizetés.</translation>
+    </message>
     <message>
         <source>Alt+A</source>
         <translation>Alt+A</translation>
@@ -1983,10 +2135,18 @@
         <source>Remove this entry</source>
         <translation>Bejegyzés eltávolítása</translation>
     </message>
+    <message>
+        <source>Use available balance</source>
+        <translation>Elérhető egyenleg használata</translation>
+    </message>
     <message>
         <source>Message:</source>
         <translation>Üzenet:</translation>
     </message>
+    <message>
+        <source>Memo:</source>
+        <translation>Jegyzet:</translation>
+    </message>
     </context>
 <context>
     <name>SendConfirmationDialog</name>
@@ -1997,6 +2157,10 @@
 </context>
 <context>
     <name>ShutdownWindow</name>
+    <message>
+        <source>%1 is shutting down...</source>
+        <translation>%1 leáll...</translation>
+    </message>
     <message>
         <source>Do not shut down the computer until this window disappears.</source>
         <translation>Ne kapcsold ki a számítógépet, amíg ez az üzenet el nem tűnik.</translation>
@@ -2004,6 +2168,10 @@
 </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>Signatures - Sign / Verify a Message</source>
+        <translation>Aláírások - Aláír / Megerősít egy Üzenetet</translation>
+    </message>
     <message>
         <source>Choose previously used address</source>
         <translation>Válasszon a korábban használt címek közül</translation>
@@ -2024,6 +2192,18 @@
         <source>Signature</source>
         <translation>Aláírás</translation>
     </message>
+    <message>
+        <source>Copy the current signature to the system clipboard</source>
+        <translation>A pillanatnyi aláírás másolása a rendszer vágólapjára</translation>
+    </message>
+    <message>
+        <source>Clear &amp;All</source>
+        <translation>&amp;Mindent töröl</translation>
+    </message>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Üzenet megerősítése</translation>
+    </message>
     <message>
         <source>The entered address is invalid.</source>
         <translation>A beírt cím érvénytelen.</translation>
@@ -2032,6 +2212,10 @@
         <source>Please check the address and try again.</source>
         <translation>Ellenőrizze a címet majd próbálja újból.</translation>
     </message>
+    <message>
+        <source>Wallet unlock was cancelled.</source>
+        <translation>A tárca feloldása elutasítva</translation>
+    </message>
     <message>
         <source>Message signing failed.</source>
         <translation>Üzenet aláírása sikertelen</translation>
@@ -2044,7 +2228,11 @@
         <source>Please check the signature and try again.</source>
         <translation>Ellenőrizze az aláírást majd próbálja újból</translation>
     </message>
-    </context>
+    <message>
+        <source>Message verified.</source>
+        <translation>Üzenet megerősítve.</translation>
+    </message>
+</context>
 <context>
     <name>SplashScreen</name>
     <message>
@@ -2101,6 +2289,10 @@
         <source>label</source>
         <translation>címke</translation>
     </message>
+    <message>
+        <source>not accepted</source>
+        <translation>nem elfogadott</translation>
+    </message>
     <message>
         <source>Transaction fee</source>
         <translation>Tranzakciós díj</translation>
@@ -2129,6 +2321,10 @@
         <source>Merchant</source>
         <translation>Kereskedő</translation>
     </message>
+    <message>
+        <source>Debug information</source>
+        <translation>Hibakeresési információk</translation>
+    </message>
     <message>
         <source>Transaction</source>
         <translation>Tranzakció</translation>
@@ -2163,6 +2359,18 @@
         <source>Label</source>
         <translation>Címke</translation>
     </message>
+    <message>
+        <source>Unconfirmed</source>
+        <translation>Nem megerősített</translation>
+    </message>
+    <message>
+        <source>Generated but not accepted</source>
+        <translation>Generált de nem elfogadott</translation>
+    </message>
+    <message>
+        <source>Sent to</source>
+        <translation>Küldés neki</translation>
+    </message>
     <message>
         <source>Mined</source>
         <translation>Bányászott</translation>
@@ -2210,6 +2418,10 @@
         <source>Range...</source>
         <translation>Tartomány...</translation>
     </message>
+    <message>
+        <source>Sent to</source>
+        <translation>Küldés neki</translation>
+    </message>
     <message>
         <source>Mined</source>
         <translation>Bányászott</translation>
@@ -2282,15 +2494,34 @@
         <source>Exporting Failed</source>
         <translation>Sikertelen export</translation>
     </message>
+    <message>
+        <source>Exporting Successful</source>
+        <translation>Sikeres exportálás</translation>
+    </message>
     </context>
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
 <context>
     <name>WalletModel</name>
+    <message>
+        <source>Send Coins</source>
+        <translation>Érmék küldése</translation>
+    </message>
+    <message>
+        <source>Increase:</source>
+        <translation>Növelés:</translation>
+    </message>
+    <message>
+        <source>New fee:</source>
+        <translation>Új díj:</translation>
+    </message>
     </context>
 <context>
     <name>WalletView</name>
@@ -2306,6 +2537,10 @@
         <source>Backup Wallet</source>
         <translation>Tárca biztonsági mentése</translation>
     </message>
+    <message>
+        <source>Wallet Data (*.dat)</source>
+        <translation>Tárca adat (*.dat)</translation>
+    </message>
     <message>
         <source>Backup Failed</source>
         <translation>Biztonsági mentés sikertelen</translation>
@@ -2317,6 +2552,38 @@
     </context>
 <context>
     <name>bitcoin-core</name>
+    <message>
+        <source>Litecoin Core</source>
+        <translation>Litecoin Mag</translation>
+    </message>
+    <message>
+        <source>Do you want to rebuild the block database now?</source>
+        <translation>Szeretnéd újra építeni a blokk adatbázist most?</translation>
+    </message>
+    <message>
+        <source>Error initializing block database</source>
+        <translation>Hiba a blokk adatbázis inicializálásakor</translation>
+    </message>
+    <message>
+        <source>Error loading block database</source>
+        <translation>Hiba a blokk adatbázis betöltésekor</translation>
+    </message>
+    <message>
+        <source>Error opening block database</source>
+        <translation>Hiba a blokk adatbázis megnyitásakor</translation>
+    </message>
+    <message>
+        <source>Error: Disk space is low!</source>
+        <translation>Hiba: Kicsi a lemezterület!</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Importálás...</translation>
+    </message>
+    <message>
+        <source>Verifying blocks...</source>
+        <translation>Blokkok megerősítése...</translation>
+    </message>
     <message>
         <source>Information</source>
         <translation>Információ</translation>
@@ -2329,14 +2596,58 @@
         <source>This is experimental software.</source>
         <translation>Ez egy fejlesztés alatt álló szoftver.</translation>
     </message>
+    <message>
+        <source>Transaction amount too small</source>
+        <translation>A tranzakció összege túl kicsi</translation>
+    </message>
+    <message>
+        <source>Transaction too large</source>
+        <translation>A tranzakció túl nagy</translation>
+    </message>
+    <message>
+        <source>Verifying wallet(s)...</source>
+        <translation>Tárca/Tárcák megerősítése</translation>
+    </message>
     <message>
         <source>Warning</source>
         <translation>Figyelmeztetés</translation>
     </message>
+    <message>
+        <source>%s is set very high!</source>
+        <translation>%s túl magasra van állítva!</translation>
+    </message>
+    <message>
+        <source>Starting network threads...</source>
+        <translation>Hálózati szálak indítása...</translation>
+    </message>
+    <message>
+        <source>Transaction amounts must not be negative</source>
+        <translation>A tranzakciók összege nem lehet negatív</translation>
+    </message>
+    <message>
+        <source>Transaction must have at least one recipient</source>
+        <translation>Legalább egy címzettnek kell lennie a tranzakcióban </translation>
+    </message>
+    <message>
+        <source>Insufficient funds</source>
+        <translation>Fedezethiány</translation>
+    </message>
+    <message>
+        <source>Loading block index...</source>
+        <translation>A blokkindex betöltése ...</translation>
+    </message>
     <message>
         <source>Loading wallet...</source>
         <translation>Tárca betöltése...</translation>
     </message>
+    <message>
+        <source>Cannot downgrade wallet</source>
+        <translation>Nem lehet lemásolni a pénztárcát</translation>
+    </message>
+    <message>
+        <source>Rescanning...</source>
+        <translation>Újraszkennelés</translation>
+    </message>
     <message>
         <source>Done loading</source>
         <translation>Betöltés kész</translation>
