@@ -179,10 +179,6 @@
         <source>Wallet encrypted</source>
         <translation>Veski dulkóðað</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 lokast núna til að dulkóðun klárist. Mundu að dulkóðun veskis kemur ekki að fullu í veg fyrir að mynt verði stolið úr tölvunni þinni með aðstoð smitforrita. </translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>MIKILVÆGT: Nýja dulkóðaða veskisskráin þarf að koma í staðinn fyrir öll fyrri afrit sem þú hefur gert af upprunalegu veskisskránni. Af öryggisástæðum munu öll fyrri afrit af ódulkóðaða veskinu verða óvirk um leið og þú byrjar að nota nýja, dulkóðaða veskið.</translation>
@@ -245,10 +241,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Yfirlit</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Hnútur</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Sýna almennt yfirlit af veski</translation>
@@ -305,14 +297,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Breyta lykilsetningu</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Sendi færslugildi...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Tek við færslugildum...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Opna &amp;URL...</translation>
@@ -365,10 +349,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Veski</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Senda</translation>
@@ -637,10 +617,6 @@
         <source>&amp;Address</source>
         <translation>Nýtt móttökufærslugildi</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Nýtt móttökufærslugildi</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Nýtt sendingarfærslugildi</translation>
@@ -806,6 +782,10 @@
         <source>Label</source>
         <translation>Merki</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Veski</translation>
+    </message>
     <message>
         <source>Resulting URI too long, try to reduce the text for label / message.</source>
         <translation>URI varð of langt, reyndu að minnka texta í merki / skilaboðum.</translation>
@@ -848,10 +828,6 @@
         <source>Change:</source>
         <translation>Skiptimynt:</translation>
     </message>
-    <message>
-        <source>Paying only the minimum fee is just fine as long as there is less transaction volume than space in the blocks. But be aware that this can end up in a never confirming transaction once there is more demand for litecoin transactions than the network can process.</source>
-        <translation>Það er í lagi að greiða einungis lágmarksupphæðina svo framarlega sem færslurúmtakið er minna en plássið í blokkunum. En gætið þess að þegar það er meiri eftirspurn eftir litecoin færslum en netið getur unnið úr þá gæti svo farið að færslurnar verða aldrei samþykktar.</translation>
-    </message>
     <message>
         <source>(Smart fee not initialized yet. This usually takes a few blocks...)</source>
         <translation>(Smart gjald er ekki gangsett ennþá. Þetta tekur venjulega nokkrar blokkir...)</translation>
@@ -907,10 +883,6 @@
         <source>Label</source>
         <translation>Merki</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Þessi blokk barst ekki í neinn annan hnútpunkt og verður sennilega ekki samþykkt!</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation>Námuunnið</translation>
@@ -954,6 +926,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
@@ -981,10 +956,6 @@
         <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
         <translation>Viðvörun: Netið er ekki í fullu samræmi! Einhver námuvinnsla virðist í ólagi.</translation>
     </message>
-    <message>
-        <source>Maximum size of data in data carrier transactions we relay and mine (default: %u)</source>
-        <translation>Hámarks gagnastærð í burðarfærslum sem við tökum við til námavinnslu (sjálfgefið: %u)</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Upplýsingar</translation>
@@ -993,14 +964,6 @@
         <source>Warning</source>
         <translation>Viðvörun</translation>
     </message>
-    <message>
-        <source>Warning: Unknown block versions being mined! It's possible unknown rules are in effect</source>
-        <translation>Viðvörun: Óþekkt blokkarútgáfa í námavinnslu! Það er mögulegt að óþekktum reglum sé fylgt</translation>
-    </message>
-    <message>
-        <source>Relay and mine data carrier transactions (default: %u)</source>
-        <translation>Hleypa í gegn og námuvinna gagnaburðarfærslur (sjálfgefið: %u)</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Villa</translation>
