@@ -183,10 +183,6 @@
         <source>Wallet encrypted</source>
         <translation>Portafoglio criptato</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 ora si chiuderà per concludere il processo di criptaggio. Ricorda che criptare il tuo portafoglio non può definitivamente proteggere i tuoi litecoin da furti tramite malware che infetta il tuo computer.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>IMPORTANTE: Qualsiasi backup precedentemente effettuato del tuo portafoglio dovrebbe essere sostituito con il nuovo file criptato generato. Per questioni di sicurezza, backup precedenti del portafoglio non criptati diverranno inutili non appena inizi ad usare il nuovo portafoglio criptato.</translation>
@@ -232,7 +228,7 @@
     </message>
     <message>
         <source>Banned Until</source>
-        <translation>bannato fino </translation>
+        <translation>Bannato fino </translation>
     </message>
 </context>
 <context>
@@ -249,10 +245,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Panoramica</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Nodo</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Mostra panoramica generale del portafoglio</translation>
@@ -309,14 +301,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>Cambia Password...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>Indirizzi di invio...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Indirizzi di ricezione...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Apri &amp;URI...</translation>
@@ -325,10 +309,6 @@
         <source>Wallet:</source>
         <translation>Portafoglio</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>Portafoglio predefinito</translation>
-    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Clicca per disabilitare attività di rete.</translation>
@@ -377,10 +357,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Portafoglio</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>Invia</translation>
@@ -485,6 +461,10 @@
         <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
         <translation>Mostra il %1 messaggio d'aiuto per ottenere una lista con le possibili opzioni per la riga di comando di Litecoin</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>Portafoglio predefinito</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -523,6 +503,14 @@
         <source>Incoming transaction</source>
         <translation>Transazione in arrivo</translation>
     </message>
+    <message>
+        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
+        <translation>Generazione  di chiavi HD &lt;b&gt;abilitata&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
+        <translation>Generazione di chiavi HD &lt;b&gt;disabilitata&lt;/b&gt;</translation>
+    </message>
     <message>
         <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
         <translation>Si è verificato un errore fatale. Litecoin non può continuare in maniera sicura e sarà chiuso.</translation>
@@ -760,7 +748,7 @@
     </message>
     <message>
         <source>The wallet will also be stored in this directory.</source>
-        <translation>Il portafoglio sara' </translation>
+        <translation>Il wallet verra' inoltre memorizzato su questa cartella.</translation>
     </message>
     <message>
         <source>Error</source>
@@ -769,6 +757,14 @@
     </context>
 <context>
     <name>ModalOverlay</name>
+    <message>
+        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the litecoin network, as detailed below.</source>
+        <translation>Le transazioni recenti potrebbero non essere ancora visibili, e quindi il saldo del wallet potrebbe essere incorretto. Questa informazione verra' corretta non appena il tuo wallet ha finito di sincronizzarsi con la rete litecoin, come specificato di seguito.</translation>
+    </message>
+    <message>
+        <source>Attempting to spend litecoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
+        <translation>Tentare di spendere litecoin che sono affetti da transazioni non ancora mostrate, non verra' accettato dal network.</translation>
+    </message>
     <message>
         <source>Number of blocks left</source>
         <translation>Numero di blocchi rimanente</translation>
@@ -806,21 +802,61 @@
         <source>Your current spendable balance</source>
         <translation>Saldo disponibile</translation>
     </message>
+    <message>
+        <source>Total:</source>
+        <translation>Totale:</translation>
+    </message>
+    <message>
+        <source>Your current total balance</source>
+        <translation>Bilancio totale attuale</translation>
+    </message>
+    <message>
+        <source>Spendable:</source>
+        <translation>Spendibile:</translation>
+    </message>
     <message>
         <source>Recent transactions</source>
         <translation>Transazioni recenti</translation>
     </message>
-    </context>
+    <message>
+        <source>Current total balance in watch-only addresses</source>
+        <translation>Bilancio totale attuale su indirizzi watch-only</translation>
+    </message>
+</context>
 <context>
     <name>PaymentServer</name>
+    <message>
+        <source>URI handling</source>
+        <translation>Gestione URI</translation>
+    </message>
+    <message>
+        <source>'litecoin://' is not a valid URI. Use 'litecoin:' instead.</source>
+        <translation>'litecoin://' non è un URI valido. Usa invece 'litecoin:'.</translation>
+    </message>
+    <message>
+        <source>Invalid payment address %1</source>
+        <translation>Indirizzo di pagamento non valido %1</translation>
+    </message>
     <message>
         <source>Payment request rejected</source>
         <translation>Richiesta di pagamento rifiutata</translation>
     </message>
+    <message>
+        <source>Payment request expired.</source>
+        <translation>Richiesta di pagamento scaduta.</translation>
+    </message>
+    <message>
+        <source>Invalid payment request.</source>
+        <translation>Richiesta di pagamento non valida.</translation>
+    </message>
     <message>
         <source>Refund from %1</source>
         <translation>Rimborso da %1</translation>
     </message>
+    <message>
+        <source>Error communicating with %1: %2</source>
+        <translation>Errore nella comunicazione con %1: %2</translation>
+    </message>
     </context>
 <context>
     <name>PeerTableModel</name>
@@ -848,10 +884,6 @@
         <source>Sent</source>
         <translation>Inviato</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>Portafoglio predefinito</translation>
-    </message>
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
@@ -948,6 +980,10 @@
         <source>Copy change</source>
         <translation>Copia cambio</translation>
     </message>
+    <message>
+        <source>Payment request expired.</source>
+        <translation>Richiesta di pagamento scaduta.</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(nessuna etichetta)</translation>
@@ -1046,12 +1082,19 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
 <context>
     <name>WalletModel</name>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>Portafoglio predefinito</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     </context>
