@@ -187,10 +187,6 @@
         <source>Wallet encrypted</source>
         <translation>საფულე დაშიფრულია</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 ახლა დაიხურება დაშიფრვის პროცესის დასასრულებლად. გახსოვდეთ, რომ თქვენი საფული დაშიფრვა სრულად არ იცავს თქვენს ბიტკოინებს მოპარვისგან მავნე პროგრამების მიერ თქვენი კომპიუტერის ინფიცირების საშუალებით.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>მნიშვნელოვანი: ნებისმიერი საფულის წინა სარეზერვო კოპია, რომელიც თქვენ შექმენით, უნდა იყოს ჩანაცვლებული ახლად გენერირებული, დაშიფრული საფულის ფაილით. უსაფრთხოების მიზნებისთვის, დაუშიფრავი საფულის ფაილის წინა სარეზევო კოპიები გახდება გამოუყენებული იმ წამსვე, როდესაც დაიწყებთ ახალი, დაშიფრული საფულის გამოყენებას.</translation>
@@ -199,6 +195,14 @@
         <source>Wallet encryption failed</source>
         <translation>საფულის დაშიფვრა წარუმატებით დამთვრდა</translation>
     </message>
+    <message>
+        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
+        <translation>საფულის დაშიფრვა ვერ მოხდა შიდა შეცდომის გამო. თქვენი საფულე არ არის დაშიფრული.</translation>
+    </message>
+    <message>
+        <source>The supplied passphrases do not match.</source>
+        <translation>მოწოდებული ფრაზა-პაროლები არ ემთხვევა ერთმანეთს.</translation>
+    </message>
     <message>
         <source>Wallet unlock failed</source>
         <translation>საფულის გახსნა წარუმატებლად შესრულდა</translation>
@@ -229,10 +233,6 @@
         <source>&amp;Overview</source>
         <translation>მიმ&amp;ოხილვა</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>კვანძი</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>საფულის ზოგადი მიმოხილვა</translation>
@@ -289,14 +289,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>ფრაზა-პაროლის შე&amp;ცვლა</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>გაგზავნის მი&amp;სამართი</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>მიღების მისამა&amp;რთი</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>&amp;URI-ის გახსნა...</translation>
@@ -305,10 +297,6 @@
         <source>Wallet:</source>
         <translation>საფულე:</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>ნაგულისხმევი საფულე</translation>
-    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>დააწკაპეთ ქსელური აქტივობის გასათიშად.</translation>
@@ -349,10 +337,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>საფულე</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;გაგზავნა</translation>
@@ -445,6 +429,14 @@
         <source>Up to date</source>
         <translation>განახლებულია</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>ნაგულისხმევი საფულე</translation>
+    </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;ფანჯარა</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 კლიენტი</translation>
@@ -753,10 +745,6 @@
         <source>Size of &amp;database cache</source>
         <translation>მონაცემთა ბაზის კეშის სი&amp;დიდე</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>სკრიპტის &amp;ვერიფიცირების ნაკადების რაოდენობა</translation>
@@ -765,10 +753,6 @@
         <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
         <translation>პროქსის IP-მისამართი (მაგ.: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>საკომანდო სტრიქონის აქტიური ოპციები, რომლებიც გადაფარავენ ზემოთნაჩვენებს:</translation>
-    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>კლიენტის ყველა პარამეტრის დაბრუნება ნაგულისხმევ მნიშვნელობებზე.</translation>
@@ -1078,10 +1062,6 @@
         <source>Clear console</source>
         <translation>კონსოლის გასუფთავება</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>ნაგულისხმევი საფულე</translation>
-    </message>
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
@@ -1512,12 +1492,19 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
 <context>
     <name>WalletModel</name>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>ნაგულისხმევი საფულე</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     </context>
