@@ -41,10 +41,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Капчык</translation>
-    </message>
     <message>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
@@ -69,6 +65,10 @@
         <source>Up to date</source>
         <translation>Жаңыланган</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Терезе</translation>
+    </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -117,10 +117,6 @@
     </context>
 <context>
     <name>OptionsDialog</name>
-    <message>
-        <source>MB</source>
-        <translation>МБ</translation>
-    </message>
     <message>
         <source>&amp;Network</source>
         <translation>&amp;Тармак</translation>
@@ -332,6 +328,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
