@@ -149,10 +149,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Pārskats</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Node</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Rādīt vispārēju maciņa pārskatu</translation>
@@ -197,14 +193,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>Mainīt &amp;Paroli...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Sūtīšanas adreses...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Saņemšanas &amp;adreses...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Atvērt &amp;URI...</translation>
@@ -241,10 +229,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Maciņš</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Sūtīt</translation>
@@ -325,6 +309,10 @@
         <source>Up to date</source>
         <translation>Sinhronizēts</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Logs</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>Sinhronizējos...</translation>
@@ -521,10 +509,6 @@
         <source>Size of &amp;database cache</source>
         <translation>&amp;Datubāzes kešatmiņas izmērs</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>Skriptu &amp;pārbaudes pavedienu skaits</translation>
@@ -537,10 +521,6 @@
         <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
         <translation>Minimizēt nevis aizvērt aplikāciju, kad logs tiek aizvērts. Kad šī iespēja ir ieslēgta, aplikācija tiks aizvērta, izvēloties Aizvērt izvēlnē.</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>Aktīvās komandrindas opcijas, kuras pārspēko šos iestatījumus:</translation>
-    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>Atiestatīt visus klienta iestatījumus uz noklusējumu.</translation>
@@ -1192,6 +1172,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
