@@ -77,10 +77,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Преглед</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Јазол</translation>
-    </message>
     <message>
         <source>&amp;Transactions</source>
         <translation>&amp;Трансакции</translation>
@@ -121,14 +117,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Измени Тајна Фраза...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Адреси за Испраќање...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Адреси за Примање...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Отвори &amp;URI...</translation>
@@ -139,7 +127,7 @@
     </message>
     <message>
         <source>Send coins to a Litecoin address</source>
-        <translation>Испрати биткоини на Биткоин адреса</translation>
+        <translation>Испрати лайткоини на Биткоин адреса</translation>
     </message>
     <message>
         <source>&amp;Verify message...</source>
@@ -149,10 +137,6 @@
         <source>Litecoin</source>
         <translation>Биткоин</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Паричник</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Испрати</translation>
@@ -197,6 +181,10 @@
         <source>Up to date</source>
         <translation>Во тек</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Прозорец</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -327,10 +315,6 @@
         <source>Options</source>
         <translation>Опции</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>МБ</translation>
-    </message>
     <message>
         <source>&amp;Network</source>
         <translation>&amp;Мрежа</translation>
@@ -578,6 +562,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
