@@ -73,10 +73,6 @@
         <source>Synchronizing with network...</source>
         <translation>Сүлжээтэй тааруулж байна...</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Нод</translation>
-    </message>
     <message>
         <source>&amp;Transactions</source>
         <translation>Гүйлгээнүүд</translation>
@@ -117,10 +113,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Нууц Үгийг Солих...</translation>
     </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Хүлээн авах хаяг</translation>
-    </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Түрүйвчийг цоожлох нууц үгийг солих</translation>
@@ -133,10 +125,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Түрүйвч</translation>
-    </message>
     <message>
         <source>&amp;Show / Hide</source>
         <translation>&amp;Харуул / Нуу</translation>
@@ -257,10 +245,6 @@
         <source>Options</source>
         <translation>Сонголтууд</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>МБ</translation>
-    </message>
     <message>
         <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
         <translation>проксигийн IP хаяг (жишээ нь: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
@@ -552,6 +536,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
