@@ -190,10 +190,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Wallet encrypted</source>
         <translation>Dompet dienkripsi</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 akan tutup untuk menyelesaikan proses enkripsi. Ingat bahawa enkripsi tidak boleh melidungi sepenuhnya litecoins anda daripada dicuri oleh malware yang menjangkiti komputer anda.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>PENTING: Apa-apa sandaran yang anda buat sebelum ini untuk fail dompet anda hendaklah digantikan dengan fail dompet enkripsi yang dijana baru. Untuk sebab-sebab keselamatan , sandaran fail dompet yang belum dibuat enkripsi sebelum ini akan menjadi tidak berguna secepat anda mula guna dompet enkripsi baru.</translation>
@@ -256,10 +252,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>&amp;Overview</source>
         <translation>&amp;Gambaran Keseluruhan</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Nod</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Tunjuk gambaran keseluruhan umum dompet</translation>
@@ -316,14 +308,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Menukar frasa-laluan</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Menghantar frasa-laluan</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Menerima frasa-laluan...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Buka &amp;URI...</translation>
@@ -332,11 +316,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Wallet:</source>
         <translation>dompet</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>dompet lalai
-</translation>
-    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Tekan untuk lumpuhkan rangkaian</translation>
@@ -385,10 +364,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>dompet</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>hantar</translation>
@@ -444,6 +419,43 @@ Alihkan fail data ke dalam tab semasa</translation>
         <translation>Tunjukkan senarai alamat dan label yang digunakan
 </translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation>Amaran</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Notis</translation>
+    </message>
+    <message>
+        <source>Up to date</source>
+        <translation>Terkini</translation>
+    </message>
+    <message>
+        <source>Open Wallet</source>
+        <translation>Buka Wallet</translation>
+    </message>
+    <message>
+        <source>Close Wallet...</source>
+        <translation>Tutup Wallet...</translation>
+    </message>
+    <message>
+        <source>Close wallet</source>
+        <translation>Tutup Wallet</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>dompet lalai
+</translation>
+    </message>
+    <message>
+        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <translation>Buka sedang Wallet &lt;b&gt;%1&lt;/b&gt;...</translation>
+    </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -475,6 +487,10 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
     </context>
 <context>
     <name>ModalOverlay</name>
@@ -484,6 +500,10 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>OptionsDialog</name>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -505,11 +525,6 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>default wallet</source>
-        <translation>dompet lalai
-</translation>
-    </message>
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
@@ -612,12 +627,24 @@ Alihkan fail data ke dalam tab semasa</translation>
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    <message>
+        <source>Close wallet</source>
+        <translation>Tutup Wallet</translation>
+    </message>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
 <context>
     <name>WalletModel</name>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>dompet lalai
+</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     <message>
@@ -628,5 +655,25 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>bitcoin-core</name>
-    </context>
+    <message>
+        <source>Information</source>
+        <translation>Notis</translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation>Amaran</translation>
+    </message>
+    <message>
+        <source>Loading wallet...</source>
+        <translation>Sedang baca wallet...</translation>
+    </message>
+    <message>
+        <source>Done loading</source>
+        <translation>Baca Selesai</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
