@@ -175,10 +175,6 @@
         <source>Wallet encrypted</source>
         <translation>Portofel criptat</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 se va inchide pentru a termina procesul de criptare. Aduți aminte că prin criptarea portofelului tău virtual, nu îți poți proteja complet monedele virtuale de a fi furate când te-ai infectat cu un virus de tip malware pe calculatorul tau.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>IMPORTANT: Fiecare backup anterior pe care l-ai facut portofelului tău virtual trebuie înlocuit cu cel nou. Din motive de securitate, backup-urile anteroiare făcute portofelului tău, care nu sunt criptate vor deveni inutilizabile și inutile când vei începe să utilizezi portofelul criptat.</translation>
@@ -241,10 +237,6 @@
         <source>&amp;Overview</source>
         <translation>Vizualizare de ansamblu</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Nod</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Arată o prezentare generală a portofelului.</translation>
@@ -297,14 +289,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Schimbă parola...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Trimite adresele...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Primește adresele...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Deschide &amp;URI...</translation>
@@ -341,10 +325,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Portofel</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Trimite</translation>
@@ -429,6 +409,10 @@
         <source>Up to date</source>
         <translation>Actual</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Fereastra</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -500,6 +484,10 @@
         <source>Change:</source>
         <translation>Schimbă:</translation>
     </message>
+    <message>
+        <source>(un)select all</source>
+        <translation>(de)selectează tot</translation>
+    </message>
     <message>
         <source>Tree mode</source>
         <translation>Mod arbore</translation>
@@ -689,10 +677,6 @@
         <source>Options</source>
         <translation>Opțiuni</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
         <translation>Adresa IP a proxy-ului (ex. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
@@ -1268,6 +1252,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
