@@ -187,10 +187,18 @@
         <source>Wallet encrypted</source>
         <translation>Кошелёк зашифрован</translation>
     </message>
+    <message>
+        <source>Your wallet is now encrypted. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
+        <translation>Бумажник зашифрован. Помните, что шифрование не способно полностью защитить Ваши лайткоины, которые могут быть украдены вредоносным ПО</translation>
+    </message>
     <message>
         <source>Wallet encryption failed</source>
         <translation>Не удалось зашифровать бумажник</translation>
     </message>
+    <message>
+        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
+        <translation>Сбой шифрования кошелька из-за внутренней ошибки. Ваш кошелёк не был зашифрован.</translation>
+    </message>
     <message>
         <source>Wallet unlock failed</source>
         <translation>Разблокировка бумажника не удалась</translation>
@@ -225,10 +233,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Обзор</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Узел</translation>
-    </message>
     <message>
         <source>&amp;Transactions</source>
         <translation>&amp;Транзакции</translation>
@@ -270,13 +274,29 @@
         <translation>&amp;Зашифровать кошелёк...</translation>
     </message>
     <message>
-        <source>Wallet</source>
+        <source>Wallet:</source>
         <translation>Кошелёк</translation>
     </message>
+    <message>
+        <source>Reindexing blocks on disk...</source>
+        <translation>Переиндексация блоков на диске...</translation>
+    </message>
+    <message>
+        <source>&amp;Debug window</source>
+        <translation>&amp;Окно отладки</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Окно</translation>
+    </message>
+    <message>
+        <source>Minimize</source>
+        <translation>Сворачивать</translation>
+    </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -337,6 +357,10 @@
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
+    <message>
+        <source>Clear</source>
+        <translation>Очистить</translation>
+    </message>
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
@@ -432,6 +456,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
@@ -457,7 +484,7 @@
     </message>
     <message>
         <source>The wallet will avoid paying less than the minimum relay fee.</source>
-        <translation>Кошелёк постарается не платить меньше, чем минимальная комиссия передачи.</translation>
+        <translation>Кошелёк будет избегать оплат меньших, нежели минимальная комиссия передачи.</translation>
     </message>
     <message>
         <source>Transaction amounts must not be negative</source>
