@@ -221,10 +221,6 @@
         <source>&amp;Options...</source>
         <translation>&amp;Opsione</translation>
     </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>Duke marr adresen</translation>
-    </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Ndrysho frazkalimin e përdorur per enkriptimin e portofolit</translation>
@@ -233,10 +229,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Portofol</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Dergo</translation>
@@ -772,6 +764,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
