@@ -187,10 +187,6 @@
         <source>Wallet encrypted</source>
         <translation>Новчаник шифриран</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 ће се сада затворити како би се завршио процес шифрирања.  Запамтите да шифрирањем свог новчаника не можете у потпуности заштити своје биткоине од крађе од стране злоћудних програма и компјутерских инфекција.</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>ВАЖНО: Свакa претходнa резерва новчаника коју сте имали треба да се замени новим, шифрираним фајлом новчаника. Из сигурносних разлога, свака претходна резерва нешифрираног фајла новчаника постаће сувишна, чим почнете да користите нови, шифрирани новчаник.</translation>
@@ -253,10 +249,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Општи преглед</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Ноде</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Погледајте општи преглед новчаника</translation>
@@ -313,14 +305,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>Промени &amp;лозинку...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Адресе за слање...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Адресе за пријем</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Отвори &amp;УРИ...</translation>
@@ -329,10 +313,6 @@
         <source>Wallet:</source>
         <translation>Новчаник</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>подразумевани новчаник</translation>
-    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Кликни да искључиш активност на мрежи.</translation>
@@ -385,10 +365,6 @@
         <source>Litecoin</source>
         <translation>Биткоин</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Новчаник</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Пошаљи</translation>
@@ -435,7 +411,7 @@
     </message>
     <message>
         <source>Request payments (generates QR codes and litecoin: URIs)</source>
-        <translation>Затражи плаћање (генерише QR кодове и биткоин: URI-е)</translation>
+        <translation>Затражи плаћање (генерише QR кодове и лайткоин: URI-е)</translation>
     </message>
     <message>
         <source>Show the list of used sending addresses and labels</source>
@@ -447,7 +423,7 @@
     </message>
     <message>
         <source>Open a litecoin: URI or payment request</source>
-        <translation>Отворите биткоин: URI или захтев за плаћање</translation>
+        <translation>Отворите лайткоин: URI или захтев за плаћање</translation>
     </message>
     <message>
         <source>&amp;Command-line options</source>
@@ -501,6 +477,10 @@
         <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
         <translation>Прикажи  поруку помоћи %1 за листу са могућим опцијама Биткоин командне линије</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>подразумевани новчаник</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 клијент</translation>
@@ -963,10 +943,6 @@
         <source>Last block time</source>
         <translation>Време последњег блока</translation>
     </message>
-    <message>
-        <source>default wallet</source>
-        <translation>подразумевани новчаник</translation>
-    </message>
     <message>
         <source>Yes</source>
         <translation>Da</translation>
@@ -1231,12 +1207,19 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
 <context>
     <name>WalletModel</name>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>подразумевани новчаник</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     <message>
