@@ -101,10 +101,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;ภาพรวม</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Node/โหนด</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>แสดงภาพรวมทั่วไปของกระเป๋าเงิน</translation>
@@ -161,14 +157,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;เปลี่ยนรหัสผ่าน...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;ที่เก็บเงิน ที่จะส่ง litecoin</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;ที่เก็บเงิน ที่จะรับ litecoin</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>เปิด &amp;URI</translation>
@@ -205,10 +193,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>กระเป๋าเงิน</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;ส่ง</translation>
@@ -321,6 +305,10 @@
         <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
         <translation>แสดง %1 ข้อความช่วยเหลือ เพื่อแสดงรายการ ตัวเลือกที่เป็นไปได้สำหรับ Litecoin command-line</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;วันโดว์</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 ลูกค้า</translation>
@@ -603,10 +591,6 @@
         <source>Size of &amp;database cache</source>
         <translation>ขนาดของ &amp;database cache</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>MB</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>จำนวนของสคริปท์ &amp;verification threads</translation>
@@ -623,10 +607,6 @@
         <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
         <translation>URL แบบอื่น (ยกตัวอย่าง เอ็กพลอเลอร์บล็อก) ที่อยู่ใน เมนูรายการ ลำดับ %s ใน URL จะถูกเปลี่ยนด้วย รายการแฮช URL ที่เป็นแบบหลายๆอัน จะถูกแยก โดย เครื่องหมายเส้นบาร์ตั้ง |</translation>
     </message>
-    <message>
-        <source>Active command-line options that override above options:</source>
-        <translation>ตัวเลือก command-line แอกทีฟอยู่นี้ จะแทนที่ ตัวเลือกด้านบนนี้:</translation>
-    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>รีเซต ไคลเอ็นออพชั่น กลับไปเป็นค่าเริ่มต้น</translation>
@@ -850,6 +830,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
