@@ -85,10 +85,6 @@
         <source>&amp;Overview</source>
         <translation>&amp;Кўриб чиқиш</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>Улам</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Ҳамённинг умумий кўринишини кўрсатиш</translation>
@@ -133,14 +129,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>Махфий сўзни &amp;ўзгартириш...</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>&amp;Жўнатилувчи манзиллар...</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>&amp;Қабул қилувчи манзиллар...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Интернет манзилни очиш</translation>
@@ -177,10 +165,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Ҳамён</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>&amp;Жўнатиш</translation>
@@ -277,6 +261,14 @@
         <source>Up to date</source>
         <translation>Янгиланган</translation>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Ойна</translation>
+    </message>
+    <message>
+        <source>Minimize</source>
+        <translation>Камайтириш</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>Банд қилинмоқда...</translation>
@@ -489,10 +481,6 @@
         <source>Size of &amp;database cache</source>
         <translation>&amp;Маълумотлар базаси кеши</translation>
     </message>
-    <message>
-        <source>MB</source>
-        <translation>МБ</translation>
-    </message>
     <message>
         <source>Number of script &amp;verification threads</source>
         <translation>Мавзуларни &amp;тўғрилаш скрипти миқдори</translation>
@@ -1160,6 +1148,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
