@@ -104,6 +104,10 @@
         <source>Label</source>
         <translation>标签</translation>
     </message>
+    <message>
+        <source>Address</source>
+        <translation>地址</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(无标签)</translation>
@@ -111,6 +115,10 @@
 </context>
 <context>
     <name>AskPassphraseDialog</name>
+    <message>
+        <source>Show password</source>
+        <translation>保存密码</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>加密钱包</translation>
@@ -176,6 +184,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Address</source>
+        <translation>地址</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>标签</translation>
@@ -244,6 +256,10 @@
         <source>Label</source>
         <translation>标签</translation>
     </message>
+    <message>
+        <source>Address</source>
+        <translation>地址</translation>
+    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>导出失败</translation>
@@ -252,6 +268,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
