@@ -179,10 +179,6 @@
         <source>Wallet encrypted</source>
         <translation>錢包已加密</translation>
     </message>
-    <message>
-        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
-        <translation>%1 現在要關閉來完成加密程序。請記得將錢包加密不能完全防止你的 Litecoins 經被入侵電腦的惡意程式偷取。</translation>
-    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>重要: 請改用新產生的加密錢包檔，來取代所以舊錢包檔的備份。為安全計，當你開始使用新的加密錢包檔後，舊錢包檔的備份就不能再使用了。</translation>
@@ -245,10 +241,6 @@
         <source>&amp;Overview</source>
         <translation>總覽 &amp;O</translation>
     </message>
-    <message>
-        <source>Node</source>
-        <translation>節點</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>顯示錢包一般總覽</translation>
@@ -305,14 +297,6 @@
         <source>&amp;Change Passphrase...</source>
         <translation>改變密碼... &amp;C</translation>
     </message>
-    <message>
-        <source>&amp;Sending addresses...</source>
-        <translation>付款位址... &amp;S</translation>
-    </message>
-    <message>
-        <source>&amp;Receiving addresses...</source>
-        <translation>收款位址... &amp;R</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>開啓網址... &amp;U</translation>
@@ -349,10 +333,6 @@
         <source>Litecoin</source>
         <translation>Litecoin</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>錢包</translation>
-    </message>
     <message>
         <source>&amp;Send</source>
         <translation>付款 &amp;S</translation>
@@ -674,6 +654,9 @@
 <context>
     <name>UnitDisplayStatusBarControl</name>
     </context>
+<context>
+    <name>WalletController</name>
+    </context>
 <context>
     <name>WalletFrame</name>
     </context>
