@@ -7,16 +7,21 @@
 #endif
 
 #include <chainparams.h>
+#include <interfaces/node.h>
+#include <qt/bitcoin.h>
+#include <qt/test/apptests.h>
 #include <qt/test/rpcnestedtests.h>
-#include <util.h>
+#include <util/system.h>
 #include <qt/test/uritests.h>
 #include <qt/test/compattests.h>
 
 #ifdef ENABLE_WALLET
 #include <qt/test/addressbooktests.h>
+#ifdef ENABLE_BIP70
 #include <qt/test/paymentservertests.h>
+#endif // ENABLE_BIP70
 #include <qt/test/wallettests.h>
-#endif
+#endif // ENABLE_WALLET
 
 #include <QApplication>
 #include <QObject>
@@ -45,12 +50,13 @@ int main(int argc, char *argv[])
 {
     SetupEnvironment();
     SetupNetworking();
-    SelectParams(CBaseChainParams::MAIN);
+    SelectParams(CBaseChainParams::REGTEST);
     noui_connect();
     ClearDatadirCache();
     fs::path pathTemp = fs::temp_directory_path() / strprintf("test_litecoin-qt_%lu_%i", (unsigned long)GetTime(), (int)GetRand(100000));
     fs::create_directories(pathTemp);
     gArgs.ForceSetArg("-datadir", pathTemp.string());
+    auto node = interfaces::MakeNode();
 
     bool fInvalid = false;
 
@@ -65,16 +71,20 @@ int main(int argc, char *argv[])
 
     // Don't remove this, it's needed to access
     // QApplication:: and QCoreApplication:: in the tests
-    QApplication app(argc, argv);
+    BitcoinApplication app(*node);
     app.setApplicationName("Litecoin-Qt-test");
 
     SSL_library_init();
 
+    AppTests app_tests(app);
+    if (QTest::qExec(&app_tests) != 0) {
+        fInvalid = true;
+    }
     URITests test1;
     if (QTest::qExec(&test1) != 0) {
         fInvalid = true;
     }
-#ifdef ENABLE_WALLET
+#if defined(ENABLE_WALLET) && defined(ENABLE_BIP70)
     PaymentServerTests test2;
     if (QTest::qExec(&test2) != 0) {
         fInvalid = true;
