@@ -3,7 +3,7 @@
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
 #include <compressor.h>
-#include <util.h>
+#include <util/system.h>
 #include <test/test_bitcoin.h>
 
 #include <stdint.h>
