@@ -1,12 +1,12 @@
 // Copyright (c) 2015-2018 The Bitcoin Core developers
-// Distributed under the MIT/X11 software license, see the accompanying
+// Distributed under the MIT software license, see the accompanying
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
 #include <chain.h>
 #include <chainparams.h>
 #include <pow.h>
 #include <random.h>
-#include <util.h>
+#include <util/system.h>
 #include <test/test_bitcoin.h>
 
 #include <boost/test/unit_test.hpp>
