@@ -12,19 +12,17 @@ class TestBitcoinCli(BitcoinTestFramework):
         self.setup_clean_chain = True
         self.num_nodes = 1
 
-    def skip_test_if_missing_module(self):
-        self.skip_if_no_wallet()
-
     def run_test(self):
         """Main test logic"""
 
         cli_response = self.nodes[0].cli("-version").send_cli()
         assert("Litecoin Core RPC client version" in cli_response)
 
-        self.log.info("Compare responses from gewalletinfo RPC and `litecoin-cli getwalletinfo`")
-        cli_response = self.nodes[0].cli.getwalletinfo()
-        rpc_response = self.nodes[0].getwalletinfo()
-        assert_equal(cli_response, rpc_response)
+        self.log.info("Compare responses from getwalletinfo RPC and `litecoin-cli getwalletinfo`")
+        if self.is_wallet_compiled():
+            cli_response = self.nodes[0].cli.getwalletinfo()
+            rpc_response = self.nodes[0].getwalletinfo()
+            assert_equal(cli_response, rpc_response)
 
         self.log.info("Compare responses from getblockchaininfo RPC and `litecoin-cli getblockchaininfo`")
         cli_response = self.nodes[0].cli.getblockchaininfo()
@@ -52,26 +50,30 @@ class TestBitcoinCli(BitcoinTestFramework):
 
         self.log.info("Compare responses from `litecoin-cli -getinfo` and the RPCs data is retrieved from.")
         cli_get_info = self.nodes[0].cli('-getinfo').send_cli()
-        wallet_info = self.nodes[0].getwalletinfo()
+        if self.is_wallet_compiled():
+            wallet_info = self.nodes[0].getwalletinfo()
         network_info = self.nodes[0].getnetworkinfo()
         blockchain_info = self.nodes[0].getblockchaininfo()
 
         assert_equal(cli_get_info['version'], network_info['version'])
         assert_equal(cli_get_info['protocolversion'], network_info['protocolversion'])
-        assert_equal(cli_get_info['walletversion'], wallet_info['walletversion'])
-        assert_equal(cli_get_info['balance'], wallet_info['balance'])
+        if self.is_wallet_compiled():
+            assert_equal(cli_get_info['walletversion'], wallet_info['walletversion'])
+            assert_equal(cli_get_info['balance'], wallet_info['balance'])
         assert_equal(cli_get_info['blocks'], blockchain_info['blocks'])
         assert_equal(cli_get_info['timeoffset'], network_info['timeoffset'])
         assert_equal(cli_get_info['connections'], network_info['connections'])
         assert_equal(cli_get_info['proxy'], network_info['networks'][0]['proxy'])
         assert_equal(cli_get_info['difficulty'], blockchain_info['difficulty'])
         assert_equal(cli_get_info['testnet'], blockchain_info['chain'] == "test")
-        assert_equal(cli_get_info['balance'], wallet_info['balance'])
-        assert_equal(cli_get_info['keypoololdest'], wallet_info['keypoololdest'])
-        assert_equal(cli_get_info['keypoolsize'], wallet_info['keypoolsize'])
-        assert_equal(cli_get_info['paytxfee'], wallet_info['paytxfee'])
-        assert_equal(cli_get_info['relayfee'], network_info['relayfee'])
-        # unlocked_until is not tested because the wallet is not encrypted
+        if self.is_wallet_compiled():
+            assert_equal(cli_get_info['balance'], wallet_info['balance'])
+            assert_equal(cli_get_info['keypoololdest'], wallet_info['keypoololdest'])
+            assert_equal(cli_get_info['keypoolsize'], wallet_info['keypoolsize'])
+            assert_equal(cli_get_info['paytxfee'], wallet_info['paytxfee'])
+            assert_equal(cli_get_info['relayfee'], network_info['relayfee'])
+            # unlocked_until is not tested because the wallet is not encrypted
+
 
 if __name__ == '__main__':
     TestBitcoinCli().main()
